@@ -89,9 +89,16 @@ class UserInterface:
     use_stty_size: bool = True
 
 
+@dataclass
+class Api:
+    port: int = 199992
+    api_polling_throttle_s: int = 5
+
+
 @dataclass
 class PlotmanConfig:
     directories: Directories
     scheduling: Scheduling
     plotting: Plotting
+    apis: Api
     user_interface: UserInterface = field(default_factory=UserInterface)
